==> moodle-1.4.3-pgsql.tgz: moodle/lang/ru/glossary.php <==
<?PHP // $Id$ 
      // glossary.php - created with Moodle 1.4 development (2004080300)


$string['addcomment'] = ' ';
$string['addentry'] = '  ';
$string['addingcomment'] = ' ';
$string['aliases'] = '() ()';
$string['allcategories'] = ' ';
$string['allentries'] = '';
$string['allowcomments'] = '   ';
$string['allowduplicatedentries'] = '  ';
$string['allowratings'] = '   ?';
$string['answer'] = '';
$string['approve'] = '';
$string['areyousuredelete'] = ' ,     ?';
$string['areyousuredeletecomment'] = ' ,     ?';
$string['areyousureexport'] = ' ,       ';
$string['ascending'] = '()';
$string['attachment'] = ' ';
$string['authorview'] = '  ';
$string['back'] = ' ';
$string['cantinsertcat'] = '  ';
$string['cantinsertrec'] = '  ';
$string['cantinsertrel'] = '   -';
$string['casesensitive'] = '    ';
$string['categories'] = '';
$string['category'] = '';
$string['categorydeleted'] = ' ';
$string['categoryview'] = '  ';
$string['cnfallowcomments'] = '           ';
$string['cnfallowdupentries'] = '           ';
$string['cnfapprovalstatus'] = '          ,   ';
$string['cnfcasesensitive'] = '   ,          ';
$string['cnfdefaulthook'] = '       ';
$string['cnfdefaultmode'] = '        ';
$string['cnffullmatch'] = '    ,        ';
$string['cnflinkentry'] = '       ';
$string['cnflinkglossaries'] = '       ';
$string['cnfrelatedview'] = '  ,        ';
$string['cnfshowgroup'] = ',        ';
$string['cnfsortkey'] = '    ';
$string['cnfsortorder'] = '    ';
$string['cnfstudentcanpost'] = ',         ';
$string['comment'] = '';
$string['commentdeleted'] = '  .';
$string['comments'] = '';
$string['commentson'] = ' ';
$string['commentupdated'] = '  ';
$string['concept'] = '';
$string['concepts'] = '';
$string['configenablerssfeeds'] = '        RSS   .            .  ';
$string['currentglossary'] = ' ';
$string['dateview'] = '  ';
$string['defaultapproval'] = '   ';
$string['definition'] = '';
$string['definitions'] = '';
$string['deleteentry'] = ' ';
$string['deletingcomment'] = ' ';
$string['deletingnoneemptycategory'] = '      ,    -       .';
$string['descending'] = '()';
$string['destination'] = '';
$string['displayformat'] = ' ';
$string['displayformatcontinuous'] = '  ';
$string['displayformats'] = ' ';
$string['displayformatssetup'] = '  ';
$string['duplicateentry'] = ' ';
$string['editcategories'] = ' ';
$string['editentry'] = ' ';
$string['editingcomment'] = ' ';
$string['entbypage'] = ',   ';
$string['entries'] = '';
$string['entrieswithoutcategory'] = '  ';
$string['entry'] = '';
$string['entryalreadyexist'] = '  ';
$string['entryapproved'] = '   ';
$string['entrydeleted'] = ' ';
$string['entryexported'] = '  ';
$string['entryishidden'] = '(   )';
$string['entryleveldefaultsettings'] = '    ';
$string['entryusedynalink'] = '    ';
$string['explainaddentry'] = '     . <br/>   -  ';
$string['explainall'] = '     ';
$string['explainalphabet'] = '     ';
$string['explainexport'] = '  . <br/>   .            .';
$string['explainimport'] = '   ,       . <p/>      .';
$string['explainspecial'] = ' ,     ';
$string['exportedentry'] = ' ';
$string['exportedfile'] = ' ';
$string['exportentries'] = ' ';
$string['exportglossary'] = ' ';
$string['exporttomainglossary'] = '   ';
$string['filetoimport'] = '  ';
$string['fillfields'] = '   -  .';
$string['filtername'] = '- ';
$string['fullmatch'] = '    ';
$string['globalglossary'] = ' ';
$string['glossaryleveldefaultsettings'] = '     ';
$string['glossarytype'] = ' ';
$string['glosssaryexported'] = ' ';
$string['importcategories'] = ' ';
$string['importedcategories'] = ' ';
$string['importedentries'] = ' ';
$string['importentries'] = ' ';
$string['isglobal'] = '  ?';
$string['linkcategory'] = '   ';
$string['mainglossary'] = ' ';
$string['maxtimehaspassed'] = ',        ($a) !';
$string['modulename'] = '';
$string['modulenameplural'] = '';
$string['newentries'] = '   ';
$string['newglossary'] = ' ';
$string['newglossarycreated'] = '  ';
$string['newglossaryentries'] = '   :';
$string['nocomment'] = '  ';
$string['nocomments'] = '(  ,      )';
$string['noconceptfound'] = '    ';
$string['noentries'] = '      ';
$string['noentry'] = '  ';
$string['notcategorised'] = '  ';
$string['numberofentries'] = ' ';
$string['onebyline'] = '(  )';
$string['printerfriendly'] = '  ';
$string['question'] = '';
$string['rate'] = '';
$string['rating'] = '';
$string['ratingeveryone'] = '   ';
$string['ratingno'] = ' ';
$string['ratingonlyteachers'] = ' $a   ';
$string['ratings'] = '';
$string['ratingssaved'] = ' ';
$string['ratingsuse'] = ' ';
$string['ratingtime'] = '       :';
$string['rejectedentries'] = ' ';
$string['rejectionrpt'] = ' ';
$string['rsssubscriberss'] = '   RSS   \'$a\' ';
$string['searchindefinition'] = ' ';
$string['secondaryglossary'] = ' ';
$string['sendinratings'] = '   ';
$string['showall'] = '  ';
$string['showalphabet'] = ' ';
$string['showspecial'] = '  ';
$string['sortby'] = '  ';
$string['sortbycreation'] = ' ';
$string['sortbylastupdate'] = ' ';
$string['sortchronogically'] = ' ';
$string['special'] = '';
$string['standardview'] = '  ';
$string['studentcanpost'] = '   ';
$string['totalentries'] = ' ';
$string['usedynalink'] = '   ';
$string['waitingapproval'] = ' ';
$string['warningstudentcapost'] = '(     )';
$string['withauthor'] = '  ';
$string['withoutauthor'] = '  ';
$string['writtenby'] = '';
$string['youarenottheauthor'] = ' -    ,       .';

?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/ru/glossary.php <==
<?PHP // $Id$ 
      // glossary.php - created with Moodle 1.4 development (2004080300)


$string['addcomment'] = ' ';
$string['addentry'] = '  ';
$string['addingcomment'] = ' ';
$string['aliases'] = '() ()';
$string['allcategories'] = ' ';
$string['allentries'] = '';
$string['allowcomments'] = '   ';
$string['allowduplicatedentries'] = '  ';
$string['allowratings'] = '   ?';
$string['answer'] = '';
$string['approve'] = '';
$string['areyousuredelete'] = ' ,     ?';
$string['areyousuredeletecomment'] = ' ,     ?';
$string['areyousureexport'] = ' ,       ';
$string['ascending'] = '()';
$string['attachment'] = ' ';
$string['authorview'] = '  ';
$string['back'] = ' ';
$string['cantinsertcat'] = '  ';
$string['cantinsertrec'] = '  ';
$string['cantinsertrel'] = '   -';
$string['casesensitive'] = '    ';
$string['categories'] = '';
$string['category'] = '';
$string['categorydeleted'] = ' ';
$string['categoryview'] = '  ';
$string['cnfallowcomments'] = ',           ';
$string['cnfallowdupentries'] = ',           ';
$string['cnfapprovalstatus'] = ',          ,   ';
$string['cnfcasesensitive'] = ',   ,     ,      ';
$string['cnfdefaulthook'] = '       ';
$string['cnfdefaultmode'] = '        ';
$string['cnffullmatch'] = ',    ,       ';
$string['cnflinkentry'] = ',       ';
$string['cnflinkglossaries'] = ',       ';
$string['cnfrelatedview'] = '  ,         ';
$string['cnfshowgroup'] = ',        ';
$string['cnfsortkey'] = '    ';
$string['cnfsortorder'] = '    ';
$string['cnfstudentcanpost'] = ',         ';
$string['comment'] = '';
$string['commentdeleted'] = '  .';
$string['comments'] = '';
$string['commentson'] = ' ';
$string['commentupdated'] = '  ';
$string['concept'] = '';
$string['concepts'] = '';
$string['configenablerssfeeds'] = '     RSS   .            .  ';
$string['currentglossary'] = ' ';
$string['dateview'] = '  ';
$string['defaultapproval'] = '   ';
$string['definition'] = '';
$string['definitions'] = '';
$string['deleteentry'] = ' ';
$string['deletingcomment'] = ' ';
$string['deletingnoneemptycategory'] = '     ,    -       .';
$string['descending'] = '()';
$string['destination'] = '';
$string['displayformat'] = ' ';
$string['displayformat2'] = ',  ';
$string['displayformat3'] = '';
$string['displayformat4'] = 'FAQ';
$string['displayformat5'] = ',  ';
$string['displayformat6'] = ' ';
$string['displayformatcontinuous'] = ',  ';
$string['displayformatdefault'] = ',  ';
$string['displayformats'] = ' ';
$string['displayformatssetup'] = '  ';
$string['duplicateentry'] = ' ';
$string['editcategories'] = ' ';
$string['editentry'] = ' ';
$string['editingcomment'] = ' ';
$string['entbypage'] = ',   ';
$string['entries'] = '';
$string['entrieswithoutcategory'] = '  ';
$string['entry'] = '';
$string['entryalreadyexist'] = '  ';
$string['entryapproved'] = '   ';
$string['entrydeleted'] = ' ';
$string['entryexported'] = '  ';
$string['entryishidden'] = '(   )';
$string['entryleveldefaultsettings'] = '    ';
$string['entryusedynalink'] = '    ';
$string['explainaddentry'] = '     . <br />   -  ';
$string['explainall'] = '     ';
$string['explainalphabet'] = ' ,   ';
$string['explainexport'] = '  . <br />   .            .';
$string['explainimport'] = '          . <br />      .';
$string['explainspecial'] = ' ,     ';
$string['exportedentry'] = ' ';
$string['exportedfile'] = ' ';
$string['exportentries'] = ' ';
$string['exportglossary'] = ' ';
$string['exporttomainglossary'] = '   ';
$string['filetoimport'] = '  ';
$string['fillfields'] = '   -  .';
$string['filtername'] = '- ';
$string['fullmatch'] = '    ';
$string['globalglossary'] = ' ';
$string['glossaryleveldefaultsettings'] = '     ';
$string['glossarytype'] = ' ';
$string['glosssaryexported'] = ' ';
$string['importcategories'] = ' ';
$string['importedcategories'] = ' ';
$string['importedentries'] = ' ';
$string['importentries'] = ' ';
$string['isglobal'] = '  ?';
$string['linkcategory'] = '   ';
$string['mainglossary'] = ' ';
$string['maxtimehaspassed'] = ',        ($a) !';
$string['modulename'] = '';
$string['modulenameplural'] = '';
$string['newentries'] = '   ';
$string['newglossary'] = ' ';
$string['newglossarycreated'] = '  ';
$string['newglossaryentries'] = '   :';
$string['nocomment'] = '  ';
$string['nocomments'] = '( ,      )';
$string['noconceptfound'] = '    ';
$string['noentries'] = '      ';
$string['noentry'] = '  ';
$string['notcategorised'] = '  ';
$string['numberofentries'] = ' ';
$string['onebyline'] = '(  )';
$string['printerfriendly'] = '  ';
$string['question'] = '';
$string['rate'] = '';
$string['rating'] = '';
$string['ratingeveryone'] = '   ';
$string['ratingno'] = ' ';
$string['ratingonlyteachers'] = ' $a   ';
$string['ratings'] = '';
$string['ratingssaved'] = ' ';
$string['ratingsuse'] = ' ';
$string['ratingtime'] = '       :';
$string['rejectedentries'] = ' ';
$string['rejectionrpt'] = ' ';
$string['rsssubscriberss'] = '   RSS   \'$a\' ';
$string['searchindefinition'] = ' ';
$string['secondaryglossary'] = ' ';
$string['sendinratings'] = '   ';
$string['showall'] = '  ';
$string['showalphabet'] = ' ';
$string['showspecial'] = '  ';
$string['sortby'] = '  ';
$string['sortbycreation'] = ' ';
$string['sortbylastupdate'] = ' ';
$string['sortchronogically'] = ' ';
$string['special'] = '';
$string['standardview'] = '  ';
$string['studentcanpost'] = '   ';
$string['totalentries'] = ' ';
$string['usedynalink'] = '   ';
$string['waitingapproval'] = ' ';
$string['warningstudentcapost'] = '(,     )';
$string['withauthor'] = '  ';
$string['withoutauthor'] = '  ';
$string['writtenby'] = '';
$string['youarenottheauthor'] = ' -    ,      .';

?>
